@@ -88,7 +88,7 @@ def run_server():
     currentPipelineFolder = os.path.abspath(os.getcwd())
     currentParentFolder = os.path.join(currentPipelineFolder,"..")
     os.environ["PYTHONPATH"] = currentPipelineFolder
-    folder = currentPipelineFolder + '/server/server.py'
+    folder = currentPipelineFolder + '/server/server_run.py'
     subprocess.call('python ' + folder, shell=True)
 
 @cli.command()
@@ -152,8 +152,10 @@ def create_project(project_name):
     create_pipeline_file(project_name, directories['main'], 'test_pipeline', False)
     # create_tester_file(project_name, directories['tester'], 'tester')
     # create_tester_file(project_name, directories['tester'], 'reporter')
-    create_tester_file(project_name, directories['server'], 'server', False)
+    create_tester_file(project_name, directories['server'], 'server_run', False)
     create_tester_file(project_name, directories['server'], 'test_server_post', False)
+    create_tester_file(project_name, directories['server'], 'pool', False)
+    create_init_file(directories['server'] + '/__init__.py', 'from server.pool import InstancePool')
     # create_tester_file(project_name, directories['trainer'], 'trainer')
     # create_pipeline_file(project_name, 'labelizer')
     # create_pipeline_file(project_name, 'pipeline')
